@@ -291,117 +291,4 @@ class BVJagged : public BV {
   }
 };
 
-
-class CharV {
-  unsigned int *raw;
-  const unsigned int nSlot;
-  const bool wrapper;
- public:
-  static const unsigned char full = 0xff;
-  static const unsigned int eltSize = 8 * sizeof(unsigned char);
-  static const unsigned int slotSize =  8 * sizeof(unsigned int);
-  static constexpr unsigned int slotElts = slotSize / eltSize;
-
-  CharV(unsigned int _nSlot);
-  CharV(unsigned int *raw_, unsigned int _nSlot);
-  ~CharV();
-
-  
-  /**
-     @brief Accessor for slot count.
-   */
-  unsigned int Slots() const {
-    return nSlot;
-  }
-  
-  /**
-     @brief Accessor for slotwise bit count.
-
-     @return count of bits per slot.
-  */
-  static unsigned int SlotElts() {
-    return slotElts;
-  }
-
-  
-  inline unsigned int *Raw(unsigned int off) {
-    return raw + off;
-  }
-
-  
-  /**
-     @brief Aligns length to smallest enclosing buffer size.
-
-     @param len is the element count to align.
-
-     @return number of buffer slots in aligned row.
-   */
-  static inline unsigned int SlotAlign(unsigned int len) {
-    return (len + slotElts - 1) / slotElts;
-  }
-
-  static inline unsigned int Stride(unsigned int len) {
-    return slotElts * SlotAlign(len);
-  }
-
-
-  inline unsigned char Get(unsigned int pos) const {
-    unsigned int slot = pos / slotElts;
-    unsigned int slotPos = pos - slot * slotElts;
-    unsigned int shiftBits = slotPos * eltSize;
-    unsigned int mask = full << shiftBits;
-    return (raw[slot] & mask) >> shiftBits;
-  }
-
-
-  /**
-     @brief sets slot at position to value passed.
-
-     @param pos is the position to set.
-
-     @return void, with side-effected raw value.
-   */
-  inline void set(unsigned int pos, unsigned char val) {
-    unsigned int slot = pos / slotElts;
-    unsigned int slotPos = pos - (slot * slotElts);
-    unsigned int shiftBits = slotPos * eltSize;
-    unsigned int mask = ~(full << shiftBits);
-    unsigned int gappedVal = raw[slot] & mask;
-    raw[slot] = gappedVal | (val << shiftBits);
-  }
-
-  /**
-     @brief Masks off all bits beyond value passed.
-
-     @return masked value.
-   */
-  inline unsigned char Mask(unsigned int pos, unsigned int del) const {
-    unsigned char val = Get(pos);
-    return val & ~(0xff << del);
-  }
-};
-
-
-/**
- */
-class CharRow : public CharV {
- public:
-  CharRow(unsigned int *raw_, unsigned int _nSlot) : CharV(raw_, _nSlot) {}
-  ~CharRow() {}
-};
-
-
-
-/**
- */
-class CharMatrix : public CharV {
-  unsigned int stride;
-  unsigned int nCol;
- public:
-  CharMatrix(unsigned int nRow, unsigned int nCol);
-  inline CharRow *Row(unsigned int row) {
-    return new CharRow(Raw((stride * row)/slotElts), stride);
-  }
-};
-
 #endif
